<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_payment');

// 记录访问日志
record_log('访问付款审核页面');

// 添加/编辑/删除应收账款处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加应收账款
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $received_amount = isset($_POST['received_amount']) ? floatval($_POST['received_amount']) : 0;
        $due_date = isset($_POST['due_date']) ? trim($_POST['due_date']) : '';

        if ($client_id <= 0 || $amount <= 0 || empty($due_date)) {
            $error = '请填写完整应收账款信息！';
        } else {
            try {
                // 计算状态
                $status = 1; // 默认未收
                if ($received_amount >= $amount) {
                    $status = 3; // 已收
                } elseif ($received_amount > 0) {
                    $status = 2; // 部分收款
                }

                // 添加应收账款
                $stmt = $pdo->prepare("INSERT INTO finance_receivables (client_id, order_id, amount, received_amount, due_date, status) VALUES (?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$client_id, $order_id, $amount, $received_amount, $due_date, $status]);

                if ($result) {
                    record_log("添加应收账款：客户ID={$client_id}，金额={$amount}");
                    $success = '应收账款记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: payment.php?success=add');
                    exit;
                } else {
                    $error = '应收账款记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑应收账款
    elseif ($_POST['action'] == 'edit') {
        $receivable_id = isset($_POST['receivable_id']) ? intval($_POST['receivable_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $received_amount = isset($_POST['received_amount']) ? floatval($_POST['received_amount']) : 0;
        $due_date = isset($_POST['due_date']) ? trim($_POST['due_date']) : '';

        if ($receivable_id <= 0 || $client_id <= 0 || $amount <= 0 || empty($due_date)) {
            $error = '请填写完整应收账款信息！';
        } else {
            try {
                // 计算状态
                $status = 1; // 默认未收
                if ($received_amount >= $amount) {
                    $status = 3; // 已收
                } elseif ($received_amount > 0) {
                    $status = 2; // 部分收款
                }

                // 更新应收账款信息
                $stmt = $pdo->prepare("UPDATE finance_receivables SET client_id = ?, order_id = ?, amount = ?, received_amount = ?, due_date = ?, status = ? WHERE id = ?");
                $result = $stmt->execute([$client_id, $order_id, $amount, $received_amount, $due_date, $status, $receivable_id]);

                if ($result) {
                    record_log("编辑应收账款：ID={$receivable_id}");
                    $success = '应收账款信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: payment.php?success=edit');
                    exit;
                } else {
                    $error = '应收账款信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除应收账款
    elseif ($_POST['action'] == 'delete') {
        $receivable_id = isset($_POST['receivable_id']) ? intval($_POST['receivable_id']) : 0;

        if ($receivable_id <= 0) {
            $error = '无效的应收账款ID！';
        } else {
            try {
                // 删除应收账款
                $stmt = $pdo->prepare("DELETE FROM finance_receivables WHERE id = ?");
                $result = $stmt->execute([$receivable_id]);

                if ($result) {
                    record_log("删除应收账款：ID={$receivable_id}");
                    $success = '应收账款记录删除成功！';
                } else {
                    $error = '应收账款记录删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 确认收款（更新已收金额）
    elseif ($_POST['action'] == 'confirm_payment') {
        $receivable_id = isset($_POST['receivable_id']) ? intval($_POST['receivable_id']) : 0;
        $payment_amount = isset($_POST['payment_amount']) ? floatval($_POST['payment_amount']) : 0;

        if ($receivable_id <= 0 || $payment_amount <= 0) {
            $error = '请填写正确的收款金额！';
        } else {
            try {
                // 获取当前应收账款信息
                $stmt = $pdo->prepare("SELECT * FROM finance_receivables WHERE id = ?");
                $stmt->execute([$receivable_id]);
                $receivable = $stmt->fetch();

                if (!$receivable) {
                    $error = '应收账款记录不存在！';
                } else {
                    // 计算新的已收金额和状态
                    $new_received = $receivable['received_amount'] + $payment_amount;
                    if ($new_received > $receivable['amount']) {
                        $error = '收款金额不能超过应收总额！';
                    } else {
                        $status = 1; // 默认未收
                        if ($new_received >= $receivable['amount']) {
                            $status = 3; // 已收
                        } elseif ($new_received > 0) {
                            $status = 2; // 部分收款
                        }

                        // 更新应收账款
                        $stmt = $pdo->prepare("UPDATE finance_receivables SET received_amount = ?, status = ? WHERE id = ?");
                        $result = $stmt->execute([$new_received, $status, $receivable_id]);

                        if ($result) {
                            // 生成收款记录
                            $receipt_no = 'SK-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);
                            $creator_id = $_SESSION['user_id'];

                            // 检查收款编号是否已存在
                            $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_receipts WHERE receipt_no = ?");
                            $stmt->execute([$receipt_no]);
                            $result = $stmt->fetch();

                            // 如果存在，重新生成
                            while ($result['count'] > 0) {
                                $receipt_no = 'SK-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);
                                $stmt->execute([$receipt_no]);
                                $result = $stmt->fetch();
                            }

                            // 添加收款记录
                            $payment_method = isset($_POST['payment_method']) ? trim($_POST['payment_method']) : '银行转账';
                            $payment_time = date('Y-m-d H:i:s');

                            $stmt = $pdo->prepare("INSERT INTO finance_receipts (receipt_no, client_id, order_id, amount, payment_method, payment_time, status, creator_id) VALUES (?, ?, ?, ?, ?, ?, 2, ?)");
                            $stmt->execute([$receipt_no, $receivable['client_id'], $receivable['order_id'], $payment_amount, $payment_method, $payment_time, $creator_id]);

                            record_log("确认收款：应收账款ID={$receivable_id}，收款金额={$payment_amount}");
                            $success = '收款确认成功！已自动生成收款记录。';
                        } else {
                            $error = '收款确认失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有应收账款
try {
    $stmt = $pdo->query("
        SELECT r.*, 
               c.client_name, 
               o.order_no
        FROM finance_receivables r
        JOIN crm_clients c ON r.client_id = c.id
        LEFT JOIN order_orders o ON r.order_id = o.id
        ORDER BY r.due_date ASC
    ");
    $receivables = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取应收账款列表失败：' . $e->getMessage();
    $receivables = [];
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有有效订单
try {
    $stmt = $pdo->query("SELECT id, order_no, client_id, amount FROM order_orders ORDER BY id DESC");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 判断是否显示表单
$show_form = false;
$edit_receivable = null;
$show_payment_form = false;
$payment_receivable = null;

// 编辑应收账款时显示表单并获取应收账款信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_receivables WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_receivable = $stmt->fetch();
        if (!$edit_receivable) {
            $error = '应收账款记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取应收账款信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 确认收款时显示表单并获取应收账款信息
if (isset($_GET['action']) && $_GET['action'] == 'confirm_payment' && isset($_GET['id'])) {
    $show_payment_form = true;
    $payment_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT r.*, c.client_name, o.order_no
            FROM finance_receivables r
            JOIN crm_clients c ON r.client_id = c.id
            LEFT JOIN order_orders o ON r.order_id = o.id
            WHERE r.id = ?
        ");
        $stmt->execute([$payment_id]);
        $payment_receivable = $stmt->fetch();
        if (!$payment_receivable) {
            $error = '应收账款记录不存在！';
            $show_payment_form = false;
        } elseif ($payment_receivable['status'] == 3) {
            $error = '此应收账款已全额收款，无需再次确认！';
            $show_payment_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取应收账款信息失败：' . $e->getMessage();
        $show_payment_form = false;
    }
}

// 添加应收账款时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '应收账款记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '应收账款信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>付款审核</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 付款审核
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="payment.php?action=add" class="btn btn-add">添加应收账款</a>
            </div>

            <!-- 添加/编辑应收账款表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_receivable ? '编辑应收账款' : '添加应收账款'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_receivable ? 'edit' : 'add'; ?>">
                        <?php if ($edit_receivable): ?>
                            <input type="hidden" name="receivable_id" value="<?php echo $edit_receivable['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_receivable && $edit_receivable['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="order_id">关联订单：</label>
                            <select id="order_id" name="order_id">
                                <option value="0">无关联订单</option>
                                <?php foreach ($orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>" <?php echo ($edit_receivable && $edit_receivable['order_id'] == $order['id']) ? 'selected' : ''; ?> data-client="<?php echo $order['client_id']; ?>" data-amount="<?php echo $order['amount']; ?>"><?php echo htmlspecialchars($order['order_no']); ?> (￥<?php echo number_format($order['amount'], 2); ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">应收金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_receivable ? htmlspecialchars($edit_receivable['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="received_amount">已收金额：</label>
                            <input type="number" id="received_amount" name="received_amount" step="0.01" min="0" value="<?php echo $edit_receivable ? htmlspecialchars($edit_receivable['received_amount']) : '0'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="due_date">到期日期：</label>
                            <input type="date" id="due_date" name="due_date" value="<?php echo $edit_receivable ? htmlspecialchars($edit_receivable['due_date']) : date('Y-m-d', strtotime('+30 days')); ?>" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="payment.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 确认收款表单 -->
            <?php if ($show_payment_form): ?>
                <div class="form-container">
                    <h3>确认收款</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="confirm_payment">
                        <input type="hidden" name="receivable_id" value="<?php echo $payment_receivable['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($payment_receivable['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>关联订单：</label>
                            <div class="form-static"><?php echo $payment_receivable['order_no'] ? htmlspecialchars($payment_receivable['order_no']) : '无关联订单'; ?></div>
                        </div>

                        <div class="form-group">
                            <label>应收金额：</label>
                            <div class="form-static"><?php echo number_format($payment_receivable['amount'], 2); ?></div>
                        </div>

                        <div class="form-group">
                            <label>已收金额：</label>
                            <div class="form-static"><?php echo number_format($payment_receivable['received_amount'], 2); ?></div>
                        </div>

                        <div class="form-group">
                            <label>未收金额：</label>
                            <div class="form-static"><?php echo number_format($payment_receivable['amount'] - $payment_receivable['received_amount'], 2); ?></div>
                        </div>

                        <div class="form-group">
                            <label for="payment_amount">本次收款金额：</label>
                            <input type="number" id="payment_amount" name="payment_amount" step="0.01" min="0" max="<?php echo $payment_receivable['amount'] - $payment_receivable['received_amount']; ?>" value="<?php echo $payment_receivable['amount'] - $payment_receivable['received_amount']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">付款方式：</label>
                            <select id="payment_method" name="payment_method" required>
                                <option value="银行转账">银行转账</option>
                                <option value="支付宝">支付宝</option>
                                <option value="微信支付">微信支付</option>
                                <option value="现金">现金</option>
                                <option value="支票">支票</option>
                                <option value="其他">其他</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">确认收款</button>
                            <a href="payment.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 应收账款列表 -->
            <div class="table-container">
                <h3>应收账款列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>客户名称</th>
                            <th>关联订单</th>
                            <th>应收金额</th>
                            <th>已收金额</th>
                            <th>未收金额</th>
                            <th>到期日期</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($receivables)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无应收账款记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($receivables as $receivable): ?>
                                <tr>
                                    <td><?php echo $receivable['id']; ?></td>
                                    <td><?php echo htmlspecialchars($receivable['client_name']); ?></td>
                                    <td><?php echo $receivable['order_no'] ? htmlspecialchars($receivable['order_no']) : '-'; ?></td>
                                    <td><?php echo number_format($receivable['amount'], 2); ?></td>
                                    <td><?php echo number_format($receivable['received_amount'], 2); ?></td>
                                    <td><?php echo number_format($receivable['amount'] - $receivable['received_amount'], 2); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($receivable['due_date'])); ?></td>
                                    <td>
                                        <?php
                                        if ($receivable['status'] == 1) echo '<span class="status-inactive">未收</span>';
                                        elseif ($receivable['status'] == 2) echo '<span class="status-pending">部分收款</span>';
                                        else echo '<span class="status-active">已收</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $receivable['create_time']; ?></td>
                                    <td>
                                        <?php if ($receivable['status'] != 3): ?>
                                            <a href="payment.php?action=confirm_payment&id=<?php echo $receivable['id']; ?>" class="btn btn-sm btn-success">确认收款</a>
                                        <?php endif; ?>
                                        <a href="payment.php?action=edit&id=<?php echo $receivable['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="receivable_id" value="<?php echo $receivable['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该应收账款记录吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>