<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_receipt');

// 记录访问日志
record_log('访问收款管理页面');

// 添加/编辑/删除收款记录处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加收款记录
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? trim($_POST['payment_method']) : '';
        $payment_time = isset($_POST['payment_time']) ? trim($_POST['payment_time']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $creator_id = $_SESSION['user_id'];

        if ($client_id <= 0 || $amount <= 0 || empty($payment_method) || empty($payment_time)) {
            $error = '请填写完整收款信息！';
        } else {
            try {
                // 生成收款编号
                $receipt_no = 'SK-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);

                // 检查收款编号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_receipts WHERE receipt_no = ?");
                $stmt->execute([$receipt_no]);
                $result = $stmt->fetch();

                // 如果存在，重新生成
                while ($result['count'] > 0) {
                    $receipt_no = 'SK-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);
                    $stmt->execute([$receipt_no]);
                    $result = $stmt->fetch();
                }

                // 添加收款记录
                $stmt = $pdo->prepare("INSERT INTO finance_receipts (receipt_no, client_id, order_id, contract_id, amount, payment_method, payment_time, status, creator_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$receipt_no, $client_id, $order_id, $contract_id, $amount, $payment_method, $payment_time, $status, $creator_id]);

                if ($result) {
                    // 如果状态为已确认，则更新应收账款
                    if ($status == 2 && $order_id) {
                        // 查找是否存在相关应收记录
                        $stmt = $pdo->prepare("SELECT id, amount, received_amount FROM finance_receivables WHERE order_id = ?");
                        $stmt->execute([$order_id]);
                        $receivable = $stmt->fetch();

                        if ($receivable) {
                            $new_received = $receivable['received_amount'] + $amount;
                            $new_status = ($new_received >= $receivable['amount']) ? 3 : 2;

                            // 更新应收记录
                            $stmt = $pdo->prepare("UPDATE finance_receivables SET received_amount = ?, status = ? WHERE id = ?");
                            $stmt->execute([$new_received, $new_status, $receivable['id']]);
                        }
                    }

                    record_log("添加收款记录：{$receipt_no}，金额：{$amount}");
                    $success = '收款记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: receipt.php?success=add');
                    exit;
                } else {
                    $error = '收款记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑收款记录
    elseif ($_POST['action'] == 'edit') {
        $receipt_id = isset($_POST['receipt_id']) ? intval($_POST['receipt_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? trim($_POST['payment_method']) : '';
        $payment_time = isset($_POST['payment_time']) ? trim($_POST['payment_time']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($receipt_id <= 0 || $client_id <= 0 || $amount <= 0 || empty($payment_method) || empty($payment_time)) {
            $error = '请填写完整收款信息！';
        } else {
            try {
                // 获取原收款记录信息
                $stmt = $pdo->prepare("SELECT * FROM finance_receipts WHERE id = ?");
                $stmt->execute([$receipt_id]);
                $old_receipt = $stmt->fetch();

                if (!$old_receipt) {
                    $error = '收款记录不存在！';
                } else {
                    // 更新收款记录
                    $stmt = $pdo->prepare("UPDATE finance_receipts SET client_id = ?, order_id = ?, contract_id = ?, amount = ?, payment_method = ?, payment_time = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$client_id, $order_id, $contract_id, $amount, $payment_method, $payment_time, $status, $receipt_id]);

                    if ($result) {
                        // 如果订单ID发生变化或状态变化，需要更新应收账款
                        if (($old_receipt['order_id'] != $order_id) || ($old_receipt['status'] != $status) || ($old_receipt['amount'] != $amount)) {
                            // 处理旧订单相关的应收账款（如果有的话）
                            if ($old_receipt['status'] == 2 && $old_receipt['order_id']) {
                                $stmt = $pdo->prepare("SELECT id, amount, received_amount FROM finance_receivables WHERE order_id = ?");
                                $stmt->execute([$old_receipt['order_id']]);
                                $old_receivable = $stmt->fetch();

                                if ($old_receivable) {
                                    $new_received = $old_receivable['received_amount'] - $old_receipt['amount'];
                                    $new_received = max(0, $new_received); // 确保不会小于0
                                    $new_status = ($new_received >= $old_receivable['amount']) ? 3 : (($new_received > 0) ? 2 : 1);

                                    // 更新旧应收记录
                                    $stmt = $pdo->prepare("UPDATE finance_receivables SET received_amount = ?, status = ? WHERE id = ?");
                                    $stmt->execute([$new_received, $new_status, $old_receivable['id']]);
                                }
                            }

                            // 处理新订单相关的应收账款（如果有的话且状态为已确认）
                            if ($status == 2 && $order_id) {
                                $stmt = $pdo->prepare("SELECT id, amount, received_amount FROM finance_receivables WHERE order_id = ?");
                                $stmt->execute([$order_id]);
                                $new_receivable = $stmt->fetch();

                                if ($new_receivable) {
                                    $new_received = $new_receivable['received_amount'] + $amount;
                                    $new_status = ($new_received >= $new_receivable['amount']) ? 3 : 2;

                                    // 更新新应收记录
                                    $stmt = $pdo->prepare("UPDATE finance_receivables SET received_amount = ?, status = ? WHERE id = ?");
                                    $stmt->execute([$new_received, $new_status, $new_receivable['id']]);
                                }
                            }
                        }

                        record_log("编辑收款记录：{$old_receipt['receipt_no']}");
                        $success = '收款记录更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: receipt.php?success=edit');
                        exit;
                    } else {
                        $error = '收款记录更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除收款记录
    elseif ($_POST['action'] == 'delete') {
        $receipt_id = isset($_POST['receipt_id']) ? intval($_POST['receipt_id']) : 0;

        if ($receipt_id <= 0) {
            $error = '无效的收款记录ID！';
        } else {
            try {
                // 获取收款记录信息
                $stmt = $pdo->prepare("SELECT * FROM finance_receipts WHERE id = ?");
                $stmt->execute([$receipt_id]);
                $receipt = $stmt->fetch();

                if (!$receipt) {
                    $error = '收款记录不存在！';
                } else {
                    // 如果状态为已确认且有关联订单，需要更新应收账款
                    if ($receipt['status'] == 2 && $receipt['order_id']) {
                        $stmt = $pdo->prepare("SELECT id, amount, received_amount FROM finance_receivables WHERE order_id = ?");
                        $stmt->execute([$receipt['order_id']]);
                        $receivable = $stmt->fetch();

                        if ($receivable) {
                            $new_received = $receivable['received_amount'] - $receipt['amount'];
                            $new_received = max(0, $new_received); // 确保不会小于0
                            $new_status = ($new_received >= $receivable['amount']) ? 3 : (($new_received > 0) ? 2 : 1);

                            // 更新应收记录
                            $stmt = $pdo->prepare("UPDATE finance_receivables SET received_amount = ?, status = ? WHERE id = ?");
                            $stmt->execute([$new_received, $new_status, $receivable['id']]);
                        }
                    }

                    // 删除收款记录
                    $stmt = $pdo->prepare("DELETE FROM finance_receipts WHERE id = ?");
                    $result = $stmt->execute([$receipt_id]);

                    if ($result) {
                        record_log("删除收款记录：{$receipt['receipt_no']}");
                        $success = '收款记录删除成功！';
                    } else {
                        $error = '收款记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有收款记录
try {
    $stmt = $pdo->query("
        SELECT r.*, 
               c.client_name, 
               o.order_no, 
               sc.contract_no,
               u.username as creator_name
        FROM finance_receipts r
        JOIN crm_clients c ON r.client_id = c.id
        LEFT JOIN order_orders o ON r.order_id = o.id
        LEFT JOIN sales_contracts sc ON r.contract_id = sc.id
        JOIN sys_users u ON r.creator_id = u.id
        ORDER BY r.payment_time DESC
    ");
    $receipts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取收款记录列表失败：' . $e->getMessage();
    $receipts = [];
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有有效订单
try {
    $stmt = $pdo->query("SELECT id, order_no, client_id, amount FROM order_orders WHERE status IN (1, 2) ORDER BY id DESC");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 获取所有有效合同
try {
    $stmt = $pdo->query("SELECT id, contract_no, client_id, amount FROM sales_contracts WHERE status = 3 ORDER BY id DESC");
    $contracts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取合同列表失败：' . $e->getMessage();
    $contracts = [];
}

// 判断是否显示表单
$show_form = false;
$edit_receipt = null;

// 编辑收款记录时显示表单并获取收款信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_receipts WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_receipt = $stmt->fetch();
        if (!$edit_receipt) {
            $error = '收款记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取收款信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加收款记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '收款记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '收款记录更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>收款管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 收款管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="receipt.php?action=add" class="btn btn-add">添加收款记录</a>
            </div>

            <!-- 添加/编辑收款记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_receipt ? '编辑收款记录' : '添加收款记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_receipt ? 'edit' : 'add'; ?>">
                        <?php if ($edit_receipt): ?>
                            <input type="hidden" name="receipt_id" value="<?php echo $edit_receipt['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_receipt && $edit_receipt['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="order_id">关联订单：</label>
                            <select id="order_id" name="order_id">
                                <option value="0">无关联订单</option>
                                <?php foreach ($orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>" <?php echo ($edit_receipt && $edit_receipt['order_id'] == $order['id']) ? 'selected' : ''; ?> data-client="<?php echo $order['client_id']; ?>" data-amount="<?php echo $order['amount']; ?>"><?php echo htmlspecialchars($order['order_no']); ?> (￥<?php echo number_format($order['amount'], 2); ?>)</option>
                                <?php endforeach; ?>
                            </select>
                            <small>注意：只显示待支付或已支付状态的订单</small>
                        </div>

                        <div class="form-group">
                            <label for="contract_id">关联合同：</label>
                            <select id="contract_id" name="contract_id">
                                <option value="0">无关联合同</option>
                                <?php foreach ($contracts as $contract): ?>
                                    <option value="<?php echo $contract['id']; ?>" <?php echo ($edit_receipt && $edit_receipt['contract_id'] == $contract['id']) ? 'selected' : ''; ?> data-client="<?php echo $contract['client_id']; ?>" data-amount="<?php echo $contract['amount']; ?>"><?php echo htmlspecialchars($contract['contract_no']); ?> (￥<?php echo number_format($contract['amount'], 2); ?>)</option>
                                <?php endforeach; ?>
                            </select>
                            <small>注意：只显示已生效的合同</small>
                        </div>

                        <div class="form-group">
                            <label for="amount">收款金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_receipt ? htmlspecialchars($edit_receipt['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">付款方式：</label>
                            <select id="payment_method" name="payment_method" required>
                                <option value="">请选择付款方式</option>
                                <option value="银行转账" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '银行转账') ? 'selected' : ''; ?>>银行转账</option>
                                <option value="支付宝" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '支付宝') ? 'selected' : ''; ?>>支付宝</option>
                                <option value="微信支付" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '微信支付') ? 'selected' : ''; ?>>微信支付</option>
                                <option value="现金" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '现金') ? 'selected' : ''; ?>>现金</option>
                                <option value="支票" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '支票') ? 'selected' : ''; ?>>支票</option>
                                <option value="其他" <?php echo ($edit_receipt && $edit_receipt['payment_method'] == '其他') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="payment_time">付款时间：</label>
                            <input type="datetime-local" id="payment_time" name="payment_time" value="<?php echo $edit_receipt ? date('Y-m-d\TH:i', strtotime($edit_receipt['payment_time'])) : date('Y-m-d\TH:i'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_receipt && $edit_receipt['status'] == 1) ? 'selected' : ''; ?>>待确认</option>
                                <option value="2" <?php echo ($edit_receipt && $edit_receipt['status'] == 2) ? 'selected' : ''; ?>>已确认</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="receipt.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 收款记录列表 -->
            <div class="table-container">
                <h3>收款记录列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>收款编号</th>
                            <th>客户名称</th>
                            <th>关联订单</th>
                            <th>关联合同</th>
                            <th>收款金额</th>
                            <th>付款方式</th>
                            <th>付款时间</th>
                            <th>状态</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($receipts)): ?>
                            <tr>
                                <td colspan="12" class="text-center">暂无收款记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($receipts as $receipt): ?>
                                <tr>
                                    <td><?php echo $receipt['id']; ?></td>
                                    <td><?php echo htmlspecialchars($receipt['receipt_no']); ?></td>
                                    <td><?php echo htmlspecialchars($receipt['client_name']); ?></td>
                                    <td><?php echo $receipt['order_no'] ? htmlspecialchars($receipt['order_no']) : '-'; ?></td>
                                    <td><?php echo $receipt['contract_no'] ? htmlspecialchars($receipt['contract_no']) : '-'; ?></td>
                                    <td><?php echo number_format($receipt['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($receipt['payment_method']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($receipt['payment_time'])); ?></td>
                                    <td>
                                        <?php
                                        if ($receipt['status'] == 1) echo '<span class="status-pending">待确认</span>';
                                        else echo '<span class="status-active">已确认</span>';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($receipt['creator_name']); ?></td>
                                    <td><?php echo $receipt['create_time']; ?></td>
                                    <td>
                                        <a href="receipt.php?action=edit&id=<?php echo $receipt['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="receipt_id" value="<?php echo $receipt['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除收款记录 \'<?php echo htmlspecialchars($receipt['receipt_no']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>