<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_reconcile');

// 记录访问日志
record_log('访问财务对账管理页面');

// 添加/编辑/删除对账单处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加对账单
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $statement_no = isset($_POST['statement_no']) ? trim($_POST['statement_no']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $received_amount = isset($_POST['received_amount']) ? floatval($_POST['received_amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $creator_id = $_SESSION['user_id'];

        if ($client_id <= 0 || empty($statement_no) || empty($start_date) || empty($end_date) || $total_amount < 0) {
            $error = '请填写完整对账单信息！';
        } else {
            try {
                // 检查对账单编号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_statements WHERE statement_no = ?");
                $stmt->execute([$statement_no]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '对账单编号已存在！';
                } else {
                    // 添加对账单
                    $stmt = $pdo->prepare("INSERT INTO finance_statements (statement_no, client_id, start_date, end_date, total_amount, received_amount, status, creator_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$statement_no, $client_id, $start_date, $end_date, $total_amount, $received_amount, $status, $creator_id]);

                    if ($result) {
                        record_log("添加对账单：{$statement_no}");
                        $success = '对账单添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: reconcile.php?success=add');
                        exit;
                    } else {
                        $error = '对账单添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑对账单
    elseif ($_POST['action'] == 'edit') {
        $statement_id = isset($_POST['statement_id']) ? intval($_POST['statement_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $statement_no = isset($_POST['statement_no']) ? trim($_POST['statement_no']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $received_amount = isset($_POST['received_amount']) ? floatval($_POST['received_amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($statement_id <= 0 || $client_id <= 0 || empty($statement_no) || empty($start_date) || empty($end_date) || $total_amount < 0) {
            $error = '请填写完整对账单信息！';
        } else {
            try {
                // 检查对账单编号是否已被其他对账单使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_statements WHERE statement_no = ? AND id != ?");
                $stmt->execute([$statement_no, $statement_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '对账单编号已被其他对账单使用！';
                } else {
                    // 更新对账单信息
                    $stmt = $pdo->prepare("UPDATE finance_statements SET client_id = ?, statement_no = ?, start_date = ?, end_date = ?, total_amount = ?, received_amount = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$client_id, $statement_no, $start_date, $end_date, $total_amount, $received_amount, $status, $statement_id]);

                    if ($result) {
                        record_log("编辑对账单：{$statement_no}");
                        $success = '对账单更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: reconcile.php?success=edit');
                        exit;
                    } else {
                        $error = '对账单更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除对账单
    elseif ($_POST['action'] == 'delete') {
        $statement_id = isset($_POST['statement_id']) ? intval($_POST['statement_id']) : 0;

        if ($statement_id <= 0) {
            $error = '无效的对账单ID！';
        } else {
            try {
                // 获取对账单信息，用于日志记录
                $stmt = $pdo->prepare("SELECT statement_no FROM finance_statements WHERE id = ?");
                $stmt->execute([$statement_id]);
                $statement = $stmt->fetch();

                if (!$statement) {
                    $error = '对账单不存在！';
                } else {
                    // 删除对账单
                    $stmt = $pdo->prepare("DELETE FROM finance_statements WHERE id = ?");
                    $result = $stmt->execute([$statement_id]);

                    if ($result) {
                        record_log("删除对账单：{$statement['statement_no']}");
                        $success = '对账单删除成功！';
                    } else {
                        $error = '对账单删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 确认对账单
    elseif ($_POST['action'] == 'confirm') {
        $statement_id = isset($_POST['statement_id']) ? intval($_POST['statement_id']) : 0;

        if ($statement_id <= 0) {
            $error = '无效的对账单ID！';
        } else {
            try {
                // 获取对账单信息
                $stmt = $pdo->prepare("SELECT * FROM finance_statements WHERE id = ?");
                $stmt->execute([$statement_id]);
                $statement = $stmt->fetch();

                if (!$statement) {
                    $error = '对账单不存在！';
                } else if ($statement['status'] == 3) {
                    $error = '对账单已确认，无需重复操作！';
                } else {
                    // 更新对账单状态为已确认
                    $stmt = $pdo->prepare("UPDATE finance_statements SET status = 3 WHERE id = ?");
                    $result = $stmt->execute([$statement_id]);

                    if ($result) {
                        record_log("确认对账单：{$statement['statement_no']}");
                        $success = '对账单已确认！';
                    } else {
                        $error = '确认对账单失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有对账单
try {
    $stmt = $pdo->query("
        SELECT s.*, 
               c.client_name, 
               u.username as creator_name
        FROM finance_statements s
        JOIN crm_clients c ON s.client_id = c.id
        JOIN sys_users u ON s.creator_id = u.id
        ORDER BY s.create_time DESC
    ");
    $statements = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取对账单列表失败：' . $e->getMessage();
    $statements = [];
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 判断是否显示表单
$show_form = false;
$edit_statement = null;

// 编辑对账单时显示表单并获取对账单信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_statements WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_statement = $stmt->fetch();
        if (!$edit_statement) {
            $error = '对账单不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取对账单信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加对账单时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '对账单添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '对账单更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务对账管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 财务对账管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="reconcile.php?action=add" class="btn btn-add">添加对账单</a>
            </div>

            <!-- 添加/编辑对账单表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_statement ? '编辑对账单' : '添加对账单'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_statement ? 'edit' : 'add'; ?>">
                        <?php if ($edit_statement): ?>
                            <input type="hidden" name="statement_id" value="<?php echo $edit_statement['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_statement && $edit_statement['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="statement_no">对账单编号：</label>
                            <input type="text" id="statement_no" name="statement_no" value="<?php echo $edit_statement ? htmlspecialchars($edit_statement['statement_no']) : ''; ?>" required>
                            <?php if (!$edit_statement): ?>
                                <small>建议格式：DZ-年月日-序号，如DZ-20230801-001</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="start_date">对账开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $edit_statement ? htmlspecialchars($edit_statement['start_date']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">对账结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $edit_statement ? htmlspecialchars($edit_statement['end_date']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="total_amount">总金额：</label>
                            <input type="number" id="total_amount" name="total_amount" step="0.01" min="0" value="<?php echo $edit_statement ? htmlspecialchars($edit_statement['total_amount']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="received_amount">已收金额：</label>
                            <input type="number" id="received_amount" name="received_amount" step="0.01" min="0" value="<?php echo $edit_statement ? htmlspecialchars($edit_statement['received_amount']) : '0.00'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_statement && $edit_statement['status'] == 1) ? 'selected' : ''; ?>>草稿</option>
                                <option value="2" <?php echo ($edit_statement && $edit_statement['status'] == 2) ? 'selected' : ''; ?>>已发送</option>
                                <option value="3" <?php echo ($edit_statement && $edit_statement['status'] == 3) ? 'selected' : ''; ?>>已确认</option>
                                <option value="4" <?php echo ($edit_statement && $edit_statement['status'] == 4) ? 'selected' : ''; ?>>已结清</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="reconcile.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 对账单列表 -->
            <div class="table-container">
                <h3>对账单列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>对账单编号</th>
                            <th>客户名称</th>
                            <th>对账期间</th>
                            <th>总金额</th>
                            <th>已收金额</th>
                            <th>状态</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($statements)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无对账单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($statements as $statement): ?>
                                <tr>
                                    <td><?php echo $statement['id']; ?></td>
                                    <td><?php echo htmlspecialchars($statement['statement_no']); ?></td>
                                    <td><?php echo htmlspecialchars($statement['client_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($statement['start_date'])); ?> 至 <?php echo date('Y-m-d', strtotime($statement['end_date'])); ?></td>
                                    <td><?php echo number_format($statement['total_amount'], 2); ?></td>
                                    <td><?php echo number_format($statement['received_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($statement['status'] == 1) echo '<span class="status-pending">草稿</span>';
                                        elseif ($statement['status'] == 2) echo '<span class="status-waiting">已发送</span>';
                                        elseif ($statement['status'] == 3) echo '<span class="status-active">已确认</span>';
                                        else echo '<span class="status-success">已结清</span>';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($statement['creator_name']); ?></td>
                                    <td><?php echo $statement['create_time']; ?></td>
                                    <td>
                                        <a href="reconcile.php?action=edit&id=<?php echo $statement['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <?php if ($statement['status'] < 3): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="confirm">
                                                <input type="hidden" name="statement_id" value="<?php echo $statement['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-primary" onclick="return confirm('确定要确认对账单 \'<?php echo htmlspecialchars($statement['statement_no']); ?>\' 吗？');">确认</button>
                                            </form>
                                        <?php endif; ?>
                                        <?php if ($statement['status'] < 3): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="statement_id" value="<?php echo $statement['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除对账单 \'<?php echo htmlspecialchars($statement['statement_no']); ?>\' 吗？');">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>