<?php
require_once '../database_config.php';

// 检查会话中是否有成功消息
if (isset($_SESSION['success_message'])) {
    $success = $_SESSION['success_message'];
    unset($_SESSION['success_message']); // 删除会话中的消息，避免重复显示
}

// 检查用户是否有权限访问此页面
check_permission_or_die('order_status');

// 记录访问日志
record_log('访问订单状态管理页面');

// 获取筛选参数
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;

// 处理订单状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 更新订单状态
    if ($_POST['action'] == 'update_status') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($order_id <= 0 || $new_status < 1 || $new_status > 5) {
            $error = '参数无效！';
        } else {
            try {
                // 获取当前订单信息
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查状态更新是否有效
                    $valid_update = false;
                    $current_status = $current_order['status'];

                    // 状态更新规则：
                    // 1(待支付) -> 2(已支付)或5(已取消)
                    // 2(已支付) -> 3(已发货)或5(已取消)
                    // 3(已发货) -> 4(已完成)或5(已取消)
                    // 4(已完成) -> 不能更改
                    // 5(已取消) -> 不能更改

                    if ($current_status == 1 && ($new_status == 2 || $new_status == 5)) {
                        $valid_update = true;
                    } elseif ($current_status == 2 && ($new_status == 3 || $new_status == 5)) {
                        $valid_update = true;
                    } elseif ($current_status == 3 && ($new_status == 4 || $new_status == 5)) {
                        $valid_update = true;
                    } elseif ($current_status == $new_status) {
                        $error = '订单已经是该状态，无需更新！';
                    } else {
                        $error = '无效的状态更新！只能按照状态流程进行更新。';
                    }

                    if ($valid_update) {
                        // 更新订单状态
                        $remark_update = '';
                        if (!empty($remark)) {
                            $remark_update = ", remark = CONCAT(IFNULL(remark, ''), '\n状态更新备注: ', ?)";
                        }

                        $sql = "UPDATE order_orders SET status = ?, update_time = NOW()" . $remark_update . " WHERE id = ?";
                        $params = empty($remark) ? [$new_status, $order_id] : [$new_status, $remark, $order_id];

                        $stmt = $pdo->prepare($sql);
                        $result = $stmt->execute($params);

                        if ($result) {
                            // 获取状态文本
                            $status_text = '';
                            if ($new_status == 1) $status_text = '待支付';
                            elseif ($new_status == 2) $status_text = '已支付';
                            elseif ($new_status == 3) $status_text = '已发货';
                            elseif ($new_status == 4) $status_text = '已完成';
                            elseif ($new_status == 5) $status_text = '已取消';

                            record_log("更新订单状态：{$current_order['order_no']}，新状态：{$status_text}");
                            $_SESSION['success_message'] = "订单状态已更新为：{$status_text}！";

                            // 重定向回当前筛选状态的页面
                            header('Location: status.php' . ($filter_status ? '?status=' . $filter_status : ''));
                            exit;
                        } else {
                            $error = '订单状态更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 状态筛选查询条件
$status_condition = '';
$status_params = [];
if ($filter_status > 0) {
    $status_condition = " WHERE o.status = ?";
    $status_params = [$filter_status];
}

// 获取所有订单
try {
    $sql = "
        SELECT o.*, c.client_name, sc.contract_no, 
               u.username as creator_name, a.username as approver_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sales_contracts sc ON o.contract_id = sc.id
        JOIN sys_users u ON o.creator_id = u.id
        LEFT JOIN sys_users a ON o.approver_id = a.id
        {$status_condition}
        ORDER BY o.update_time DESC, o.create_time DESC
    ";

    $stmt = $pdo->prepare($sql);
    if (!empty($status_params)) {
        $stmt->execute($status_params);
    } else {
        $stmt->execute();
    }

    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 获取各状态订单数量
try {
    $stmt = $pdo->query("
        SELECT status, COUNT(*) as count 
        FROM order_orders 
        GROUP BY status
    ");
    $status_counts = [];
    while ($row = $stmt->fetch()) {
        $status_counts[$row['status']] = $row['count'];
    }
} catch (PDOException $e) {
    $error = '获取订单状态统计失败：' . $e->getMessage();
    $status_counts = [];
}

// 获取总订单数
$total_orders = array_sum($status_counts);

// 判断是否显示状态更新表单
$show_update_form = false;
$order_to_update = null;

// 显示状态更新表单
if (isset($_GET['action']) && $_GET['action'] == 'update' && isset($_GET['id'])) {
    $show_update_form = true;
    $order_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT o.*, c.client_name
            FROM order_orders o
            JOIN crm_clients c ON o.client_id = c.id
            WHERE o.id = ?
        ");
        $stmt->execute([$order_id]);
        $order_to_update = $stmt->fetch();

        if (!$order_to_update) {
            $error = '订单不存在！';
            $show_update_form = false;
        } elseif ($order_to_update['status'] == 4 || $order_to_update['status'] == 5) {
            $error = '已完成或已取消的订单不能再更新状态！';
            $show_update_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取订单信息失败：' . $e->getMessage();
        $show_update_form = false;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单状态管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 订单状态管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 订单状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>全部订单</h3>
                    <div class="number"><?php echo $total_orders; ?></div>
                    <div class="desc"><a href="status.php">查看全部</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>待支付订单</h3>
                    <div class="number"><?php echo isset($status_counts[1]) ? $status_counts[1] : 0; ?></div>
                    <div class="desc"><a href="status.php?status=1">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已支付订单</h3>
                    <div class="number"><?php echo isset($status_counts[2]) ? $status_counts[2] : 0; ?></div>
                    <div class="desc"><a href="status.php?status=2">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已发货订单</h3>
                    <div class="number"><?php echo isset($status_counts[3]) ? $status_counts[3] : 0; ?></div>
                    <div class="desc"><a href="status.php?status=3">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已完成订单</h3>
                    <div class="number"><?php echo isset($status_counts[4]) ? $status_counts[4] : 0; ?></div>
                    <div class="desc"><a href="status.php?status=4">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已取消订单</h3>
                    <div class="number"><?php echo isset($status_counts[5]) ? $status_counts[5] : 0; ?></div>
                    <div class="desc"><a href="status.php?status=5">筛选查看</a></div>
                </div>
            </div>

            <!-- 订单状态更新表单 -->
            <?php if ($show_update_form && $order_to_update): ?>
                <div class="form-container">
                    <h3>更新订单状态 - 订单编号: <?php echo htmlspecialchars($order_to_update['order_no']); ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="order_id" value="<?php echo $order_to_update['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($order_to_update['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>当前状态：</label>
                            <div class="form-static">
                                <?php
                                if ($order_to_update['status'] == 1) echo '<span class="status-pending">待支付</span>';
                                elseif ($order_to_update['status'] == 2) echo '<span class="status-pending">已支付</span>';
                                elseif ($order_to_update['status'] == 3) echo '<span class="status-pending">已发货</span>';
                                ?>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="new_status">新状态：</label>
                            <select id="new_status" name="new_status" required>
                                <?php if ($order_to_update['status'] == 1): ?>
                                    <option value="2">已支付</option>
                                    <option value="5">已取消</option>
                                <?php elseif ($order_to_update['status'] == 2): ?>
                                    <option value="3">已发货</option>
                                    <option value="5">已取消</option>
                                <?php elseif ($order_to_update['status'] == 3): ?>
                                    <option value="4">已完成</option>
                                    <option value="5">已取消</option>
                                <?php endif; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3" placeholder="可选，输入状态更新的原因或相关信息"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">更新状态</button>
                            <a href="status.php<?php echo $filter_status ? '?status=' . $filter_status : ''; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 订单列表 -->
            <div class="table-container">
                <h3>
                    <?php
                    if ($filter_status == 1) echo '待支付订单列表';
                    elseif ($filter_status == 2) echo '已支付订单列表';
                    elseif ($filter_status == 3) echo '已发货订单列表';
                    elseif ($filter_status == 4) echo '已完成订单列表';
                    elseif ($filter_status == 5) echo '已取消订单列表';
                    else echo '全部订单列表';
                    ?>
                </h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>关联合同</th>
                            <th>金额</th>
                            <th>支付方式</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>最后更新</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($orders)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无订单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                    <td><?php echo $order['contract_no'] ? htmlspecialchars($order['contract_no']) : '-'; ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($order['payment_method'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($order['status'] == 1) echo '<span class="status-pending">待支付</span>';
                                        elseif ($order['status'] == 2) echo '<span class="status-pending">已支付</span>';
                                        elseif ($order['status'] == 3) echo '<span class="status-pending">已发货</span>';
                                        elseif ($order['status'] == 4) echo '<span class="status-active">已完成</span>';
                                        elseif ($order['status'] == 5) echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    <td><?php echo $order['update_time'] ? date('Y-m-d H:i', strtotime($order['update_time'])) : '-'; ?></td>
                                    <td>
                                        <?php if ($order['status'] < 4): // 不是已完成或已取消 
                                        ?>
                                            <a href="status.php?action=update&id=<?php echo $order['id']; ?><?php echo $filter_status ? '&status=' . $filter_status : ''; ?>" class="btn btn-sm btn-edit">更新状态</a>
                                        <?php else: ?>
                                            <span class="text-muted">无需操作</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 状态说明 -->
            <div class="info-box">
                <h3>订单状态说明</h3>
                <ul>
                    <li><strong>待支付</strong>：订单已创建，等待客户付款。可以更新为"已支付"或"已取消"。</li>
                    <li><strong>已支付</strong>：客户已支付订单金额，等待发货。可以更新为"已发货"或"已取消"。</li>
                    <li><strong>已发货</strong>：商品已发货，等待客户确认收货。可以更新为"已完成"或"已取消"。</li>
                    <li><strong>已完成</strong>：订单交易已完成。状态不可再更改。</li>
                    <li><strong>已取消</strong>：订单已取消。状态不可再更改。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>