<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('performance_assess');

// 记录访问日志
record_log('访问业绩考核页面');

// 检查当前用户是否为管理员(假设角色ID=1为管理员)
$is_admin = ($_SESSION['role_id'] == 1);

// 添加考核
if ($_POST['action'] == 'add' && $is_admin) {
    $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
    $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
    $month = isset($_POST['month']) ? intval($_POST['month']) : date('n');
    $target_amount = isset($_POST['target_amount']) ? floatval($_POST['target_amount']) : 0;
    $target_clients = isset($_POST['target_clients']) ? intval($_POST['target_clients']) : 0;
    $team_id = isset($_POST['team_id']) && !empty($_POST['team_id']) ? intval($_POST['team_id']) : null;

    if ($user_id <= 0 || $target_amount <= 0 || $target_clients <= 0) {
        $error = '请填写有效的考核信息！';
    } else {
        try {
            // 检查是否已存在该月份的考核
            $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM perf_assessments WHERE user_id = ? AND year = ? AND month = ?");
            $stmt->execute([$user_id, $year, $month]);
            $result = $stmt->fetch();

            if ($result['count'] > 0) {
                $error = '该用户的此月份考核记录已存在！';
            } else {
                // 添加考核记录
                $stmt = $pdo->prepare("INSERT INTO perf_assessments (user_id, team_id, year, month, target_amount, target_clients) VALUES (?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$user_id, $team_id, $year, $month, $target_amount, $target_clients]);

                if ($result) {
                    record_log("创建{$year}年{$month}月业绩考核");
                    $success = '业绩考核创建成功！';
                    header('Location: assess.php?success=add');
                    exit;
                } else {
                    $error = '业绩考核创建失败！';
                }
            }
        } catch (PDOException $e) {
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 添加/更新考核处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 更新考核
    if ($_POST['action'] == 'assess') {
        $assessment_id = isset($_POST['assessment_id']) ? intval($_POST['assessment_id']) : 0;
        $score = isset($_POST['score']) ? floatval($_POST['score']) : 0;
        $level = isset($_POST['level']) ? intval($_POST['level']) : 0;
        $comment = isset($_POST['comment']) ? trim($_POST['comment']) : '';
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;
        $actual_clients = isset($_POST['actual_clients']) ? intval($_POST['actual_clients']) : 0;

        if ($assessment_id <= 0 || $score < 0 || $score > 100 || $level < 1 || $level > 5) {
            $error = '请填写有效的考核信息！';
        } else {
            try {
                // 验证考核记录是否存在
                $stmt = $pdo->prepare("SELECT * FROM perf_assessments WHERE id = ?");
                $stmt->execute([$assessment_id]);
                $assessment = $stmt->fetch();

                if (!$assessment) {
                    $error = '考核记录不存在！';
                } else if (!$is_admin && $assessment['user_id'] != $_SESSION['user_id']) {
                    $error = '您没有权限修改此考核记录！';
                } else {
                    // 更新考核记录
                    if ($is_admin) {
                        $stmt = $pdo->prepare("UPDATE perf_assessments SET actual_amount = ?, actual_clients = ?, score = ?, level = ?, comment = ?, assessor_id = ? WHERE id = ?");
                        $result = $stmt->execute([$actual_amount, $actual_clients, $score, $level, $comment, $_SESSION['user_id'], $assessment_id]);
                    } else {
                        // 非管理员只能更新实际销售额和客户数
                        $stmt = $pdo->prepare("UPDATE perf_assessments SET actual_amount = ?, actual_clients = ? WHERE id = ? AND user_id = ?");
                        $result = $stmt->execute([$actual_amount, $actual_clients, $assessment_id, $_SESSION['user_id']]);
                    }

                    if ($result) {
                        record_log("更新业绩考核：{$assessment['year']}年{$assessment['month']}月");
                        $success = '业绩考核更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: assess.php?success=assess');
                        exit;
                    } else {
                        $error = '业绩考核更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : 0; // 默认显示所有年份
$filter_month = isset($_GET['month']) ? intval($_GET['month']) : 0; // 0表示所有月份
$filter_user = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0; // 0表示所有用户

// 构建查询条件
$filter_where = "";
if (!$is_admin) {
    // 非管理员只能查看自己的数据
    $filter_where = "WHERE user_id = {$_SESSION['user_id']}";
} else if ($filter_user > 0) {
    // 管理员且选择了特定用户
    $filter_where = "WHERE user_id = {$filter_user}";
} else {
    // 管理员查看所有数据
    $filter_where = "WHERE 1=1";
}

// 添加年份和月份筛选
if ($filter_year > 0) {
    $filter_where .= " AND year = {$filter_year}";
}
if ($filter_month > 0) {
    $filter_where .= " AND month = {$filter_month}";
}

// 获取所有业绩考核
try {
    $stmt = $pdo->query("
        SELECT a.*, t.team_name, u.username, u2.username as assessor_name
        FROM perf_assessments a
        LEFT JOIN perf_teams t ON a.team_id = t.id
        LEFT JOIN sys_users u ON a.user_id = u.id
        LEFT JOIN sys_users u2 ON a.assessor_id = u2.id
        {$filter_where}
        ORDER BY a.year DESC, a.month DESC
    ");
    $assessments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取业绩考核列表失败：' . $e->getMessage();
    $assessments = [];
}

// 获取所有用户列表 - 用于管理员筛选
$users_list = [];
if ($is_admin) {
    try {
        $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY id");
        $users_list = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取用户列表失败：' . $e->getMessage();
    }
}

// 判断是否显示考核表单
$show_form = false;
$edit_assessment = null;

// 编辑考核时显示表单并获取考核信息
if (isset($_GET['action']) && $_GET['action'] == 'assess' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT a.*, t.team_name, u.username 
            FROM perf_assessments a
            LEFT JOIN perf_teams t ON a.team_id = t.id
            LEFT JOIN sys_users u ON a.user_id = u.id
            WHERE a.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_assessment = $stmt->fetch();

        // 验证权限
        if (!$edit_assessment) {
            $error = '考核记录不存在！';
            $show_form = false;
        } else if (!$is_admin && $edit_assessment['user_id'] != $_SESSION['user_id']) {
            $error = '您没有权限修改此考核记录！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取考核信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 获取可选年份
$years = [];
$current_year = date('Y');
for ($i = $current_year - 2; $i <= $current_year + 1; $i++) {
    $years[] = $i;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'assess') {
        $success = '业绩考核更新成功！';
    } elseif ($_GET['success'] == 'add') {
        $success = '业绩考核创建成功！';
    }
}

// 添加考核时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add' && $is_admin) {
    $show_form = true;
    $add_form = true; // 标记为添加表单
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>业绩考核</h2>
            <div class="breadcrumb">
                <a href="index.php">人员绩效与KPI</a> &gt; 业绩考核
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 添加操作栏，放在筛选表单前面 -->
            <div class="action-bar">
                <?php if ($is_admin): ?>
                    <a href="assess.php?action=add" class="btn btn-add">添加业绩考核</a>
                <?php endif; ?>
            </div>
            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="year">年份：</label>
                            <select id="year" name="year">
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $filter_year == $year ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="month">月份：</label>
                            <select id="month" name="month">
                                <option value="0">全部月份</option>
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo $filter_month == $i ? 'selected' : ''; ?>>
                                        <?php echo $i; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <?php if ($is_admin): ?>
                            <div class="filter-item">
                                <label for="user_id">用户：</label>
                                <select id="user_id" name="user_id">
                                    <option value="0">全部用户</option>
                                    <?php foreach ($users_list as $user): ?>
                                        <option value="<?php echo $user['id']; ?>" <?php echo $filter_user == $user['id'] ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($user['username']); ?> (ID:<?php echo $user['id']; ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>
                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="assess.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>


            <!-- 考核表单 -->
            <?php if ($show_form && (!isset($add_form) || !$add_form)): ?>
                <div class="form-container">
                    <h3>业绩考核</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="assess">
                        <input type="hidden" name="assessment_id" value="<?php echo $edit_assessment['id']; ?>">

                        <div class="form-group">
                            <label>年月：</label>
                            <div class="form-control-static">
                                <?php echo $edit_assessment['year']; ?>年<?php echo $edit_assessment['month']; ?>月
                            </div>
                        </div>

                        <div class="form-group">
                            <label>用户：</label>
                            <div class="form-control-static">
                                <?php echo htmlspecialchars($edit_assessment['username']); ?> (ID:<?php echo $edit_assessment['user_id']; ?>)
                            </div>
                        </div>

                        <?php if ($edit_assessment['team_name']): ?>
                            <div class="form-group">
                                <label>所属团队：</label>
                                <div class="form-control-static">
                                    <?php echo htmlspecialchars($edit_assessment['team_name']); ?>
                                </div>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label>目标销售额：</label>
                            <div class="form-control-static">
                                <?php echo number_format($edit_assessment['target_amount'], 2); ?>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="actual_amount">实际销售额：</label>
                            <input type="number" id="actual_amount" name="actual_amount" min="0" step="0.01" value="<?php echo $edit_assessment['actual_amount']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label>目标客户数：</label>
                            <div class="form-control-static">
                                <?php echo $edit_assessment['target_clients']; ?>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="actual_clients">实际客户数：</label>
                            <input type="number" id="actual_clients" name="actual_clients" min="0" step="1" value="<?php echo $edit_assessment['actual_clients']; ?>" required>
                        </div>

                        <?php if ($is_admin): ?>
                            <div class="form-group">
                                <label for="score">考核得分：</label>
                                <input type="number" id="score" name="score" min="0" max="100" step="0.01" value="<?php echo $edit_assessment['score']; ?>">
                                <small class="form-text">评分范围：0-100分</small>
                            </div>

                            <div class="form-group">
                                <label for="level">考核等级：</label>
                                <select id="level" name="level">
                                    <option value="1" <?php echo $edit_assessment['level'] == 1 ? 'selected' : ''; ?>>A (优秀)</option>
                                    <option value="2" <?php echo $edit_assessment['level'] == 2 ? 'selected' : ''; ?>>B (良好)</option>
                                    <option value="3" <?php echo $edit_assessment['level'] == 3 ? 'selected' : ''; ?>>C (合格)</option>
                                    <option value="4" <?php echo $edit_assessment['level'] == 4 ? 'selected' : ''; ?>>D (需改进)</option>
                                    <option value="5" <?php echo $edit_assessment['level'] == 5 ? 'selected' : ''; ?>>E (不合格)</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="comment">考核评语：</label>
                                <textarea id="comment" name="comment" rows="3" class="form-control"><?php echo htmlspecialchars($edit_assessment['comment']); ?></textarea>
                            </div>
                        <?php endif; ?>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="assess.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 添加考核表单 -->
            <?php if ($show_form && isset($add_form) && $add_form): ?>
                <div class="form-container">
                    <h3>添加业绩考核</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="user_id">选择用户：</label>
                            <select id="user_id" name="user_id" required>
                                <option value="">-- 请选择用户 --</option>
                                <?php foreach ($users_list as $user): ?>
                                    <option value="<?php echo $user['id']; ?>">
                                        <?php echo htmlspecialchars($user['username']); ?> (ID:<?php echo $user['id']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="year">年份：</label>
                            <select id="year" name="year" required>
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $year == date('Y') ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="month">月份：</label>
                            <select id="month" name="month" required>
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo $i == date('n') ? 'selected' : ''; ?>>
                                        <?php echo $i; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="team_id">关联团队：</label>
                            <select id="team_id" name="team_id">
                                <option value="">-- 无关联团队 --</option>
                                <?php
                                try {
                                    $stmt = $pdo->query("SELECT id, team_name FROM perf_teams ORDER BY team_name");
                                    $teams = $stmt->fetchAll();
                                    foreach ($teams as $team) {
                                        echo "<option value='{$team['id']}'>" . htmlspecialchars($team['team_name']) . "</option>";
                                    }
                                } catch (PDOException $e) {
                                    echo "<option value=''>获取团队列表失败</option>";
                                }
                                ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="target_amount">目标销售额：</label>
                            <input type="number" id="target_amount" name="target_amount" min="0" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="target_clients">目标客户数：</label>
                            <input type="number" id="target_clients" name="target_clients" min="0" step="1" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="assess.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 业绩考核列表 -->
            <div class="table-container">
                <h3>业绩考核列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>年月</th>
                            <?php if ($is_admin || $filter_user > 0): ?>
                                <th>用户</th>
                            <?php endif; ?>
                            <th>目标销售额</th>
                            <th>实际销售额</th>
                            <th>销售完成率</th>
                            <th>目标客户数</th>
                            <th>实际客户数</th>
                            <th>客户完成率</th>
                            <th>考核得分</th>
                            <th>考核等级</th>
                            <th>考核人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($assessments)): ?>
                            <tr>
                                <td colspan="<?php echo $is_admin || $filter_user > 0 ? 12 : 11; ?>" class="text-center">暂无业绩考核数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($assessments as $assessment): ?>
                                <tr>
                                    <td><?php echo $assessment['year']; ?>年<?php echo $assessment['month']; ?>月</td>

                                    <?php if ($is_admin || $filter_user > 0): ?>
                                        <td><?php echo htmlspecialchars($assessment['username']); ?></td>
                                    <?php endif; ?>

                                    <td><?php echo number_format($assessment['target_amount'], 2); ?></td>
                                    <td><?php echo number_format($assessment['actual_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($assessment['target_amount'] > 0) {
                                            $sales_rate = ($assessment['actual_amount'] / $assessment['target_amount']) * 100;
                                            echo number_format($sales_rate, 2) . '%';

                                            if ($sales_rate >= 100) {
                                                echo ' <span style="color: #28a745;">(已达标)</span>';
                                            } elseif ($sales_rate >= 80) {
                                                echo ' <span style="color: #ffc107;">(接近达标)</span>';
                                            } else {
                                                echo ' <span style="color: #dc3545;">(未达标)</span>';
                                            }
                                        } else {
                                            echo '-';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $assessment['target_clients']; ?></td>
                                    <td><?php echo $assessment['actual_clients']; ?></td>
                                    <td>
                                        <?php
                                        if ($assessment['target_clients'] > 0) {
                                            $client_rate = ($assessment['actual_clients'] / $assessment['target_clients']) * 100;
                                            echo number_format($client_rate, 2) . '%';

                                            if ($client_rate >= 100) {
                                                echo ' <span style="color: #28a745;">(已达标)</span>';
                                            } elseif ($client_rate >= 80) {
                                                echo ' <span style="color: #ffc107;">(接近达标)</span>';
                                            } else {
                                                echo ' <span style="color: #dc3545;">(未达标)</span>';
                                            }
                                        } else {
                                            echo '-';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $assessment['score'] ? number_format($assessment['score'], 2) : '-'; ?></td>
                                    <td>
                                        <?php
                                        if ($assessment['level']) {
                                            $level_labels = ['', 'A (优秀)', 'B (良好)', 'C (合格)', 'D (需改进)', 'E (不合格)'];
                                            $level_colors = ['', '#28a745', '#4CAF50', '#ffc107', '#fd7e14', '#dc3545'];
                                            echo '<span style="color: ' . $level_colors[$assessment['level']] . ';">' . $level_labels[$assessment['level']] . '</span>';
                                        } else {
                                            echo '-';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $assessment['assessor_name'] ? htmlspecialchars($assessment['assessor_name']) : '-'; ?></td>
                                    <td>
                                        <a href="assess.php?action=assess&id=<?php echo $assessment['id']; ?>" class="btn btn-sm btn-edit">
                                            <?php echo $is_admin ? '考核' : '更新数据'; ?>
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于业绩考核</h3>
                <p>业绩考核功能帮助您：</p>
                <ul>
                    <li><strong>记录实际业绩</strong>：记录每月实际的销售额和客户开发数量。</li>
                    <li><strong>自动计算完成率</strong>：系统自动计算目标的完成率，直观展示业绩表现。</li>
                    <?php if ($is_admin): ?>
                        <li><strong>综合评分考核</strong>：管理员可以根据业绩表现进行评分和评级。</li>
                        <li><strong>添加考核评语</strong>：为员工提供具体的反馈和改进建议。</li>
                    <?php endif; ?>
                    <li><strong>绩效档案</strong>：记录并追踪历史业绩表现，形成完整的绩效档案。</li>
                </ul>
                <p>提示：业绩考核是激励机制的重要依据，也是个人成长和团队发展的关键参考。</p>
            </div>
        </div>
    </div>
</body>

</html>