<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_client');

// 记录访问日志
record_log('访问客户增长分析页面');

// 获取分析数据的时间范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-6 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $report_type = isset($_POST['report_type']) ? intval($_POST['report_type']) : 1;

        if (empty($title) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的报表信息！';
        } else {
            try {
                // 获取客户增长分析模板
                $stmt = $pdo->prepare("SELECT id FROM report_templates WHERE category = 1 AND name LIKE '%客户增长%' LIMIT 1");
                $stmt->execute();
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到客户增长分析模板！';
                } else {
                    // 构建查询参数
                    $params = json_encode([
                        'start_date' => $start_date,
                        'end_date' => $end_date,
                        'report_type' => $report_type
                    ]);

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '客户增长分析_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径 - 修改为使用相对于网站根目录的路径
                    $web_file_path = 'report/reports/' . $file_name; // 关键修改：添加report/前缀

                    // 根据报表类型获取相应的数据
                    if ($report_type == 1 || $report_type == 3) {
                        // 获取月度新增客户数据
                        $stmt = $pdo->prepare("
                            SELECT 
                                DATE_FORMAT(create_time, '%Y-%m') as month, 
                                COUNT(*) as new_clients 
                            FROM crm_clients 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY month 
                            ORDER BY month
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $monthly_data = $stmt->fetchAll();
                    }

                    if ($report_type == 1 || $report_type == 2) {
                        // 获取客户级别分布
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN client_level = 1 THEN 'VIP客户'
                                    WHEN client_level = 2 THEN '普通客户'
                                    WHEN client_level = 3 THEN '潜在客户'
                                    ELSE '其他'
                                END as level_name,
                                COUNT(*) as count
                            FROM crm_clients 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY client_level
                            ORDER BY client_level
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $level_data = $stmt->fetchAll();

                        // 获取客户类型分布
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN client_type = 1 THEN '企业客户'
                                    WHEN client_type = 2 THEN '个人客户'
                                    ELSE '其他'
                                END as type_name,
                                COUNT(*) as count
                            FROM crm_clients 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY client_type
                            ORDER BY client_type
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $type_data = $stmt->fetchAll();

                        // 获取行业分布
                        $stmt = $pdo->prepare("
                            SELECT 
                                IFNULL(industry, '未分类') as industry_name,
                                COUNT(*) as count
                            FROM crm_clients 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY industry
                            ORDER BY count DESC
                            LIMIT 10
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $industry_data = $stmt->fetchAll();
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    fputcsv($file, []);  // 空行

                    // 写入月度趋势数据
                    if ($report_type == 1 || $report_type == 3) {
                        fputcsv($file, ['月度客户增长趋势']);
                        fputcsv($file, ['月份', '新增客户数']);
                        foreach ($monthly_data as $row) {
                            fputcsv($file, [$row['month'], $row['new_clients']]);
                        }
                        fputcsv($file, []);  // 空行
                    }

                    // 写入客户级别分布
                    if ($report_type == 1 || $report_type == 2) {
                        fputcsv($file, ['客户级别分布']);
                        fputcsv($file, ['客户级别', '数量', '占比']);
                        $total = 0;
                        foreach ($level_data as $level) {
                            $total += $level['count'];
                        }
                        foreach ($level_data as $level) {
                            $percentage = $total > 0 ? round(($level['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$level['level_name'], $level['count'], $percentage . '%']);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入客户类型分布
                        fputcsv($file, ['客户类型分布']);
                        fputcsv($file, ['客户类型', '数量', '占比']);
                        $total = 0;
                        foreach ($type_data as $type) {
                            $total += $type['count'];
                        }
                        foreach ($type_data as $type) {
                            $percentage = $total > 0 ? round(($type['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$type['type_name'], $type['count'], $percentage . '%']);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入行业分布
                        fputcsv($file, ['客户行业分布（Top 10）']);
                        fputcsv($file, ['行业', '客户数量', '占比']);
                        $total = 0;
                        foreach ($industry_data as $industry) {
                            $total += $industry['count'];
                        }
                        foreach ($industry_data as $industry) {
                            $percentage = $total > 0 ? round(($industry['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$industry['industry_name'], $industry['count'], $percentage . '%']);
                        }
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template['id'], $title, $params, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成客户增长分析报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取月度新增客户数据
try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(create_time, '%Y-%m') as month, 
            COUNT(*) as new_clients 
        FROM crm_clients 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY month 
        ORDER BY month
    ");
    $stmt->execute([$start_date, $end_date]);
    $monthly_growth = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取月度新增客户数据失败：' . $e->getMessage();
    $monthly_growth = [];
}

// 获取客户级别分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN client_level = 1 THEN 'VIP客户'
                WHEN client_level = 2 THEN '普通客户'
                WHEN client_level = 3 THEN '潜在客户'
                ELSE '其他'
            END as level_name,
            COUNT(*) as count
        FROM crm_clients 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY client_level
        ORDER BY client_level
    ");
    $stmt->execute([$start_date, $end_date]);
    $client_levels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户级别分布数据失败：' . $e->getMessage();
    $client_levels = [];
}

// 获取客户类型分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN client_type = 1 THEN '企业客户'
                WHEN client_type = 2 THEN '个人客户'
                ELSE '其他'
            END as type_name,
            COUNT(*) as count
        FROM crm_clients 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY client_type
        ORDER BY client_type
    ");
    $stmt->execute([$start_date, $end_date]);
    $client_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户类型分布数据失败：' . $e->getMessage();
    $client_types = [];
}

// 获取行业分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            IFNULL(industry, '未分类') as industry_name,
            COUNT(*) as count
        FROM crm_clients 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY industry
        ORDER BY count DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $industry_distribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取行业分布数据失败：' . $e->getMessage();
    $industry_distribution = [];
}

// 获取最近生成的客户增长分析报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        WHERE t.category = 1 AND t.name LIKE '%客户增长%'
        ORDER BY r.create_time DESC
        LIMIT 5
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 计算统计数据
$total_new_clients = 0;
foreach ($monthly_growth as $month) {
    $total_new_clients += $month['new_clients'];
}

// 计算平均月度增长
$month_count = count($monthly_growth);
$avg_monthly_growth = $month_count > 0 ? round($total_new_clients / $month_count, 2) : 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户增长分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 客户增长分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">查询</button>
                    </div>
                </form>
            </div>

            <!-- 统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总新增客户</h3>
                    <div class="number"><?php echo $total_new_clients; ?></div>
                    <div class="desc">所选时间范围内新增客户总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>平均月度增长</h3>
                    <div class="number"><?php echo $avg_monthly_growth; ?></div>
                    <div class="desc">每月平均新增客户数</div>
                </div>

                <div class="dashboard-card">
                    <h3>企业/个人比例</h3>
                    <div class="number">
                        <?php
                        $enterprise_count = 0;
                        $personal_count = 0;
                        foreach ($client_types as $type) {
                            if ($type['type_name'] == '企业客户') $enterprise_count = $type['count'];
                            if ($type['type_name'] == '个人客户') $personal_count = $type['count'];
                        }
                        echo $enterprise_count > 0 && $personal_count > 0 ?
                            round($enterprise_count / $personal_count, 2) . ':1' : ($enterprise_count > 0 ? '仅企业' : ($personal_count > 0 ? '仅个人' : '0'));
                        ?>
                    </div>
                    <div class="desc">企业客户与个人客户比例</div>
                </div>
            </div>

            <!-- 月度增长趋势 -->
            <div class="section">
                <h3>月度客户增长趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>新增客户数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_growth)): ?>
                            <tr>
                                <td colspan="2" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($monthly_growth as $month): ?>
                                <tr>
                                    <td><?php echo $month['month']; ?></td>
                                    <td><?php echo $month['new_clients']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 客户级别分布 -->
            <div class="section">
                <h3>客户级别分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>客户级别</th>
                            <th>数量</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($client_levels)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($client_levels as $level) {
                                $total += $level['count'];
                            }
                            foreach ($client_levels as $level):
                                $percentage = $total > 0 ? round(($level['count'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo $level['level_name']; ?></td>
                                    <td><?php echo $level['count']; ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 客户行业分布 -->
            <div class="section">
                <h3>客户行业分布（Top 10）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>行业</th>
                            <th>客户数量</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($industry_distribution)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($industry_distribution as $industry) {
                                $total += $industry['count'];
                            }
                            foreach ($industry_distribution as $industry):
                                $percentage = $total > 0 ? round(($industry['count'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($industry['industry_name']); ?></td>
                                    <td><?php echo $industry['count']; ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成报表</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="generate">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="客户增长分析报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_start_date">统计开始日期：</label>
                        <input type="date" id="report_start_date" name="start_date" value="<?php echo $start_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_end_date">统计结束日期：</label>
                        <input type="date" id="report_end_date" name="end_date" value="<?php echo $end_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型：</label>
                        <select id="report_type" name="report_type">
                            <option value="1">完整报表（包含所有数据）</option>
                            <option value="2">简化报表（仅包含关键指标）</option>
                            <option value="3">趋势报表（侧重增长趋势）</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>历史报表记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于客户增长分析</h3>
                <p>客户增长分析帮助您了解：</p>
                <ul>
                    <li><strong>新增客户趋势</strong>：监控每月新增客户数量，发现增长或下降趋势。</li>
                    <li><strong>客户构成</strong>：分析客户级别、类型和行业分布，了解客户结构。</li>
                    <li><strong>转化效果</strong>：追踪潜在客户转化为正式客户的效果。</li>
                    <li><strong>客户留存</strong>：分析客户留存率，评估服务满意度。</li>
                </ul>
                <p>定期分析客户增长数据，可以帮助您制定更有效的市场策略和服务改进计划。</p>
            </div>
        </div>
    </div>
</body>

</html>