<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_client');

// 获取报表ID
$report_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($report_id <= 0) {
    die('无效的报表ID');
}

try {
    // 获取报表信息
    $stmt = $pdo->prepare("
        SELECT r.*, t.name as template_name
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id
        WHERE r.id = ?
    ");
    $stmt->execute([$report_id]);
    $report = $stmt->fetch();

    if (!$report) {
        die('找不到报表记录');
    }

    // 解析参数
    $params = json_decode($report['params'], true);
    $start_date = $params['start_date'] ?? date('Y-m-d', strtotime('-6 months'));
    $end_date = $params['end_date'] ?? date('Y-m-d');
    $report_type = $params['report_type'] ?? 1;

    // 设置HTTP头，使浏览器直接下载
    $file_name = '客户增长分析_' . date('YmdHis') . '.csv';
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename="' . $file_name . '"');

    // 打开输出流
    $output = fopen('php://output', 'w');

    // 写入BOM头，确保Excel正确显示中文
    fputs($output, "\xEF\xBB\xBF");

    // 获取数据并写入CSV
    // 写入标题
    fputcsv($output, [$report['title']]);
    fputcsv($output, ['报表生成时间：' . date('Y-m-d H:i:s')]);
    fputcsv($output, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
    fputcsv($output, []);  // 空行

    // 根据报表类型获取相应的数据
    if ($report_type == 1 || $report_type == 3) {
        // 获取月度新增客户数据
        $stmt = $pdo->prepare("
            SELECT 
                DATE_FORMAT(create_time, '%Y-%m') as month, 
                COUNT(*) as new_clients 
            FROM crm_clients 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY month 
            ORDER BY month
        ");
        $stmt->execute([$start_date, $end_date]);
        $monthly_data = $stmt->fetchAll();

        // 写入月度趋势数据
        fputcsv($output, ['月度客户增长趋势']);
        fputcsv($output, ['月份', '新增客户数']);
        foreach ($monthly_data as $row) {
            fputcsv($output, [$row['month'], $row['new_clients']]);
        }
        fputcsv($output, []);  // 空行
    }

    if ($report_type == 1 || $report_type == 2) {
        // 获取客户级别分布
        $stmt = $pdo->prepare("
            SELECT 
                CASE 
                    WHEN client_level = 1 THEN 'VIP客户'
                    WHEN client_level = 2 THEN '普通客户'
                    WHEN client_level = 3 THEN '潜在客户'
                    ELSE '其他'
                END as level_name,
                COUNT(*) as count
            FROM crm_clients 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY client_level
            ORDER BY client_level
        ");
        $stmt->execute([$start_date, $end_date]);
        $level_data = $stmt->fetchAll();

        // 写入客户级别分布
        fputcsv($output, ['客户级别分布']);
        fputcsv($output, ['客户级别', '数量', '占比']);
        $total = 0;
        foreach ($level_data as $level) {
            $total += $level['count'];
        }
        foreach ($level_data as $level) {
            $percentage = $total > 0 ? round(($level['count'] / $total) * 100, 2) : 0;
            fputcsv($output, [$level['level_name'], $level['count'], $percentage . '%']);
        }
        fputcsv($output, []);  // 空行

        // 获取客户类型分布
        $stmt = $pdo->prepare("
            SELECT 
                CASE 
                    WHEN client_type = 1 THEN '企业客户'
                    WHEN client_type = 2 THEN '个人客户'
                    ELSE '其他'
                END as type_name,
                COUNT(*) as count
            FROM crm_clients 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY client_type
            ORDER BY client_type
        ");
        $stmt->execute([$start_date, $end_date]);
        $type_data = $stmt->fetchAll();

        // 写入客户类型分布
        fputcsv($output, ['客户类型分布']);
        fputcsv($output, ['客户类型', '数量', '占比']);
        $total = 0;
        foreach ($type_data as $type) {
            $total += $type['count'];
        }
        foreach ($type_data as $type) {
            $percentage = $total > 0 ? round(($type['count'] / $total) * 100, 2) : 0;
            fputcsv($output, [$type['type_name'], $type['count'], $percentage . '%']);
        }
        fputcsv($output, []);  // 空行

        // 获取行业分布
        $stmt = $pdo->prepare("
            SELECT 
                IFNULL(industry, '未分类') as industry_name,
                COUNT(*) as count
            FROM crm_clients 
            WHERE create_time BETWEEN ? AND ? 
            GROUP BY industry
            ORDER BY count DESC
            LIMIT 10
        ");
        $stmt->execute([$start_date, $end_date]);
        $industry_data = $stmt->fetchAll();

        // 写入行业分布
        fputcsv($output, ['客户行业分布（Top 10）']);
        fputcsv($output, ['行业', '客户数量', '占比']);
        $total = 0;
        foreach ($industry_data as $industry) {
            $total += $industry['count'];
        }
        foreach ($industry_data as $industry) {
            $percentage = $total > 0 ? round(($industry['count'] / $total) * 100, 2) : 0;
            fputcsv($output, [$industry['industry_name'], $industry['count'], $percentage . '%']);
        }
    }

    // 记录下载日志
    record_log("下载客户增长分析报表：{$report['title']}");

    // 关闭输出流并退出
    fclose($output);
    exit;
} catch (Exception $e) {
    die('系统错误：' . $e->getMessage());
}
