<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_client');

// 记录访问日志
record_log('访问客户满意度分析页面');

// 获取分析数据的时间范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-6 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $report_type = isset($_POST['report_type']) ? intval($_POST['report_type']) : 1;

        if (empty($title) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的报表信息！';
        } else {
            try {
                // 获取客户满意度分析模板
                $stmt = $pdo->prepare("SELECT id FROM report_templates WHERE category = 4 AND name LIKE '%客户满意度%' LIMIT 1");
                $stmt->execute();
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到客户满意度分析模板！';
                } else {
                    // 构建查询参数
                    $params = json_encode([
                        'start_date' => $start_date,
                        'end_date' => $end_date,
                        'report_type' => $report_type
                    ]);

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '客户满意度分析_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径 - 修改为使用相对于网站根目录的路径
                    $web_file_path = 'report/reports/' . $file_name; // 关键修改：添加report/前缀

                    // 根据报表类型获取相应的数据
                    if ($report_type == 1 || $report_type == 3) {
                        // 获取月度满意度趋势数据
                        $stmt = $pdo->prepare("
                            SELECT 
                                DATE_FORMAT(create_time, '%Y-%m') as month, 
                                ROUND(AVG(score), 2) as avg_score,
                                COUNT(*) as total_ratings
                            FROM service_satisfaction 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY month 
                            ORDER BY month
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $monthly_data = $stmt->fetchAll();
                    }

                    if ($report_type == 1 || $report_type == 2) {
                        // 获取评分分布
                        $stmt = $pdo->prepare("
                            SELECT 
                                score,
                                COUNT(*) as count
                            FROM service_satisfaction 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY score
                            ORDER BY score DESC
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $score_distribution = $stmt->fetchAll();

                        // 获取工单处理情况
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN type = 1 THEN '咨询'
                                    WHEN type = 2 THEN '投诉'
                                    WHEN type = 3 THEN '故障'
                                    WHEN type = 4 THEN '建议'
                                    ELSE '其他'
                                END as type_name,
                                COUNT(*) as total,
                                SUM(CASE WHEN status = 3 THEN 1 ELSE 0 END) as completed,
                                ROUND(SUM(CASE WHEN status = 3 THEN 1 ELSE 0 END) / COUNT(*) * 100, 2) as completion_rate
                            FROM service_tickets 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY type
                            ORDER BY type
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $ticket_data = $stmt->fetchAll();

                        // 获取客户反馈情况
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN type = 1 THEN '产品反馈'
                                    WHEN type = 2 THEN '服务反馈'
                                    ELSE '其他反馈'
                                END as type_name,
                                COUNT(*) as total,
                                SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) as processed,
                                ROUND(SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) / COUNT(*) * 100, 2) as process_rate
                            FROM service_feedback 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY type
                            ORDER BY type
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $feedback_data = $stmt->fetchAll();
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    fputcsv($file, []);  // 空行

                    // 写入月度趋势数据
                    if ($report_type == 1 || $report_type == 3) {
                        fputcsv($file, ['月度满意度趋势']);
                        fputcsv($file, ['月份', '平均评分', '评价数量']);
                        foreach ($monthly_data as $row) {
                            fputcsv($file, [$row['month'], $row['avg_score'], $row['total_ratings']]);
                        }
                        fputcsv($file, []);  // 空行
                    }

                    // 写入评分分布
                    if ($report_type == 1 || $report_type == 2) {
                        fputcsv($file, ['客户评分分布']);
                        fputcsv($file, ['评分', '数量', '占比']);
                        $total = 0;
                        foreach ($score_distribution as $score) {
                            $total += $score['count'];
                        }
                        foreach ($score_distribution as $score) {
                            $percentage = $total > 0 ? round(($score['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$score['score'], $score['count'], $percentage . '%']);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入工单处理情况
                        fputcsv($file, ['工单处理情况']);
                        fputcsv($file, ['工单类型', '总数', '已完成', '完成率']);
                        foreach ($ticket_data as $ticket) {
                            fputcsv($file, [
                                $ticket['type_name'],
                                $ticket['total'],
                                $ticket['completed'],
                                $ticket['completion_rate'] . '%'
                            ]);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入客户反馈情况
                        fputcsv($file, ['客户反馈情况']);
                        fputcsv($file, ['反馈类型', '总数', '已处理', '处理率']);
                        foreach ($feedback_data as $feedback) {
                            fputcsv($file, [
                                $feedback['type_name'],
                                $feedback['total'],
                                $feedback['processed'],
                                $feedback['process_rate'] . '%'
                            ]);
                        }
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template['id'], $title, $params, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成客户满意度分析报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取月度满意度趋势数据
try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(create_time, '%Y-%m') as month, 
            ROUND(AVG(score), 2) as avg_score,
            COUNT(*) as total_ratings
        FROM service_satisfaction 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY month 
        ORDER BY month
    ");
    $stmt->execute([$start_date, $end_date]);
    $monthly_trends = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取月度满意度趋势数据失败：' . $e->getMessage();
    $monthly_trends = [];
}

// 获取评分分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            score,
            COUNT(*) as count
        FROM service_satisfaction 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY score
        ORDER BY score DESC
    ");
    $stmt->execute([$start_date, $end_date]);
    $score_distribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取评分分布数据失败：' . $e->getMessage();
    $score_distribution = [];
}

// 获取工单处理情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN type = 1 THEN '咨询'
                WHEN type = 2 THEN '投诉'
                WHEN type = 3 THEN '故障'
                WHEN type = 4 THEN '建议'
                ELSE '其他'
            END as type_name,
            COUNT(*) as total,
            SUM(CASE WHEN status = 3 THEN 1 ELSE 0 END) as completed,
            ROUND(SUM(CASE WHEN status = 3 THEN 1 ELSE 0 END) / COUNT(*) * 100, 2) as completion_rate
        FROM service_tickets 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY type
        ORDER BY type
    ");
    $stmt->execute([$start_date, $end_date]);
    $ticket_analysis = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取工单处理情况数据失败：' . $e->getMessage();
    $ticket_analysis = [];
}

// 获取客户反馈情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN type = 1 THEN '产品反馈'
                WHEN type = 2 THEN '服务反馈'
                ELSE '其他反馈'
            END as type_name,
            COUNT(*) as total,
            SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) as processed,
            ROUND(SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) / COUNT(*) * 100, 2) as process_rate
        FROM service_feedback 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY type
        ORDER BY type
    ");
    $stmt->execute([$start_date, $end_date]);
    $feedback_analysis = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户反馈情况数据失败：' . $e->getMessage();
    $feedback_analysis = [];
}

// 获取最近的评价内容
try {
    $stmt = $pdo->prepare("
        SELECT 
            s.id,
            s.client_id,
            c.client_name,
            s.score,
            s.comment,
            s.create_time
        FROM service_satisfaction s
        JOIN crm_clients c ON s.client_id = c.id
        WHERE s.create_time BETWEEN ? AND ? AND s.comment IS NOT NULL AND s.comment != ''
        ORDER BY s.create_time DESC
        LIMIT 5
    ");
    $stmt->execute([$start_date, $end_date]);
    $recent_comments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最近评价内容失败：' . $e->getMessage();
    $recent_comments = [];
}

// 获取最近生成的客户满意度分析报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        WHERE t.category = 4 AND t.name LIKE '%客户满意度%'
        ORDER BY r.create_time DESC
        LIMIT 5
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 计算统计数据
$total_ratings = 0;
$sum_score = 0;
foreach ($monthly_trends as $month) {
    $total_ratings += $month['total_ratings'];
    $sum_score += ($month['avg_score'] * $month['total_ratings']);
}

// 计算平均满意度
$avg_satisfaction = $total_ratings > 0 ? round($sum_score / $total_ratings, 2) : 0;

// 计算投诉处理率
$total_complaints = 0;
$completed_complaints = 0;
foreach ($ticket_analysis as $ticket) {
    if ($ticket['type_name'] == '投诉') {
        $total_complaints = $ticket['total'];
        $completed_complaints = $ticket['completed'];
        break;
    }
}
$complaint_process_rate = $total_complaints > 0 ? round(($completed_complaints / $total_complaints) * 100, 2) : 0;

// 计算高评分占比(4-5分)
$high_score_count = 0;
$total_score_count = 0;
foreach ($score_distribution as $score) {
    $total_score_count += $score['count'];
    if ($score['score'] >= 4) {
        $high_score_count += $score['count'];
    }
}
$high_score_rate = $total_score_count > 0 ? round(($high_score_count / $total_score_count) * 100, 2) : 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户满意度分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 客户满意度分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">查询</button>
                    </div>
                </form>
            </div>

            <!-- 统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>平均满意度评分</h3>
                    <div class="number"><?php echo $avg_satisfaction; ?></div>
                    <div class="desc">所选时间范围内客户评分均值（1-5分）</div>
                </div>

                <div class="dashboard-card">
                    <h3>投诉处理率</h3>
                    <div class="number"><?php echo $complaint_process_rate; ?>%</div>
                    <div class="desc">投诉工单完成数/总投诉工单数</div>
                </div>

                <div class="dashboard-card">
                    <h3>高评分占比</h3>
                    <div class="number"><?php echo $high_score_rate; ?>%</div>
                    <div class="desc">4-5分评价占总评价的比例</div>
                </div>
            </div>

            <!-- 月度满意度趋势 -->
            <div class="section">
                <h3>月度满意度趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>平均评分</th>
                            <th>评价数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_trends)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($monthly_trends as $month): ?>
                                <tr>
                                    <td><?php echo $month['month']; ?></td>
                                    <td><?php echo $month['avg_score']; ?></td>
                                    <td><?php echo $month['total_ratings']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 评分分布 -->
            <div class="section">
                <h3>客户评分分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>评分</th>
                            <th>数量</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($score_distribution)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($score_distribution as $score) {
                                $total += $score['count'];
                            }
                            foreach ($score_distribution as $score):
                                $percentage = $total > 0 ? round(($score['count'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo $score['score']; ?></td>
                                    <td><?php echo $score['count']; ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 工单处理情况 -->
            <div class="section">
                <h3>工单处理情况</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>工单类型</th>
                            <th>总数</th>
                            <th>已完成</th>
                            <th>完成率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($ticket_analysis)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($ticket_analysis as $ticket): ?>
                                <tr>
                                    <td><?php echo $ticket['type_name']; ?></td>
                                    <td><?php echo $ticket['total']; ?></td>
                                    <td><?php echo $ticket['completed']; ?></td>
                                    <td><?php echo $ticket['completion_rate']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 客户反馈情况 -->
            <div class="section">
                <h3>客户反馈情况</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>反馈类型</th>
                            <th>总数</th>
                            <th>已处理</th>
                            <th>处理率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($feedback_analysis)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($feedback_analysis as $feedback): ?>
                                <tr>
                                    <td><?php echo $feedback['type_name']; ?></td>
                                    <td><?php echo $feedback['total']; ?></td>
                                    <td><?php echo $feedback['processed']; ?></td>
                                    <td><?php echo $feedback['process_rate']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近客户评价 -->
            <div class="section">
                <h3>最近客户评价</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>客户名称</th>
                            <th>评分</th>
                            <th>评价内容</th>
                            <th>评价时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($recent_comments)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($recent_comments as $comment): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($comment['client_name']); ?></td>
                                    <td><?php echo $comment['score']; ?></td>
                                    <td><?php echo htmlspecialchars($comment['comment']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($comment['create_time'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成报表</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="generate">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="客户满意度分析报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_start_date">统计开始日期：</label>
                        <input type="date" id="report_start_date" name="start_date" value="<?php echo $start_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_end_date">统计结束日期：</label>
                        <input type="date" id="report_end_date" name="end_date" value="<?php echo $end_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型：</label>
                        <select id="report_type" name="report_type">
                            <option value="1">完整报表（包含所有数据）</option>
                            <option value="2">详细报表（重点分析满意度分布与工单处理情况）</option>
                            <option value="3">趋势报表（侧重满意度月度变化）</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>历史报表记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于客户满意度分析</h3>
                <p>客户满意度分析帮助您了解：</p>
                <ul>
                    <li><strong>客户评分趋势</strong>：监控每月客户满意度评分的变化，发现提升或下降的趋势。</li>
                    <li><strong>工单处理效率</strong>：分析不同类型工单的完成率，评估客服团队的响应和解决能力。</li>
                    <li><strong>投诉处理情况</strong>：跟踪投诉的处理情况和速度，提高客户问题解决率。</li>
                    <li><strong>客户反馈情况</strong>：了解客户对产品和服务的反馈处理情况，发现改进空间。</li>
                </ul>
                <p>定期分析客户满意度数据，可以帮助您提高服务质量，增强客户忠诚度，降低客户流失率。</p>
            </div>
        </div>
    </div>
</body>

</html>