<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service_feedback');

// 记录访问日志
record_log('访问客户反馈管理页面');

// 添加/编辑/处理反馈
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加反馈
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';

        if ($client_id <= 0 || empty($content)) {
            $error = '请填写完整反馈信息！';
        } else {
            try {
                // 添加反馈
                $stmt = $pdo->prepare("INSERT INTO service_feedback (client_id, type, content, status) VALUES (?, ?, ?, 0)");
                $result = $stmt->execute([$client_id, $type, $content]);

                if ($result) {
                    record_log("添加客户反馈：{$content}");
                    $success = '反馈添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: feedback.php?success=add');
                    exit;
                } else {
                    $error = '反馈添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 处理反馈状态
    elseif ($_POST['action'] == 'update_status') {
        $feedback_id = isset($_POST['feedback_id']) ? intval($_POST['feedback_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 0;

        if ($feedback_id <= 0) {
            $error = '无效的反馈ID！';
        } else {
            try {
                // 更新反馈状态
                $stmt = $pdo->prepare("UPDATE service_feedback SET status = ? WHERE id = ?");
                $result = $stmt->execute([$status, $feedback_id]);

                if ($result) {
                    $status_text = $status == 1 ? '已处理' : '未处理';
                    record_log("更新反馈ID：{$feedback_id} 状态为：{$status_text}");
                    $success = '反馈状态更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: feedback.php?success=update');
                    exit;
                } else {
                    $error = '反馈状态更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除反馈
    elseif ($_POST['action'] == 'delete') {
        $feedback_id = isset($_POST['feedback_id']) ? intval($_POST['feedback_id']) : 0;

        if ($feedback_id <= 0) {
            $error = '无效的反馈ID！';
        } else {
            try {
                // 删除反馈
                $stmt = $pdo->prepare("DELETE FROM service_feedback WHERE id = ?");
                $result = $stmt->execute([$feedback_id]);

                if ($result) {
                    record_log("删除反馈ID：{$feedback_id}");
                    $success = '反馈删除成功！';
                } else {
                    $error = '反馈删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选参数
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : -1;
$type_filter = isset($_GET['type']) ? intval($_GET['type']) : 0;

// 构建筛选条件
$where_conditions = [];
$params = [];

if ($status_filter >= 0) {
    $where_conditions[] = "f.status = ?";
    $params[] = $status_filter;
}

if ($type_filter > 0) {
    $where_conditions[] = "f.type = ?";
    $params[] = $type_filter;
}

$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 获取所有反馈
try {
    $sql = "SELECT f.*, c.client_name 
            FROM service_feedback f
            JOIN crm_clients c ON f.client_id = c.id 
            {$where_clause}
            ORDER BY f.create_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $feedbacks = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取反馈列表失败：' . $e->getMessage();
    $feedbacks = [];
}

// 获取所有客户，用于添加反馈
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 判断是否显示表单
$show_form = false;

// 添加反馈时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '反馈添加成功！';
    } elseif ($_GET['success'] == 'update') {
        $success = '反馈状态更新成功！';
    }
}

// 统计各种状态的反馈数量
$pending_count = 0;
$processed_count = 0;

foreach ($feedbacks as $feedback) {
    if ($feedback['status'] == 0) {
        $pending_count++;
    } else {
        $processed_count++;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户反馈管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户服务与售后</a> &gt; 客户反馈管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 反馈状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>未处理反馈</h3>
                    <div class="number"><?php echo $pending_count; ?></div>
                    <div class="desc"><a href="?status=0">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已处理反馈</h3>
                    <div class="number"><?php echo $processed_count; ?></div>
                    <div class="desc"><a href="?status=1">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>反馈总数</h3>
                    <div class="number"><?php echo count($feedbacks); ?></div>
                    <div class="desc"><a href="feedback.php">全部反馈</a></div>
                </div>
            </div>

            <div class="action-bar">
                <a href="feedback.php?action=add" class="btn btn-add">添加反馈</a>
            </div>

            <!-- 添加反馈表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3>添加反馈</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="client_id">选择客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>"><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">反馈类型：</label>
                            <select id="type" name="type">
                                <option value="1">产品</option>
                                <option value="2">服务</option>
                                <option value="3">其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="content">反馈内容：</label>
                            <textarea id="content" name="content" rows="4" required></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">提交反馈</button>
                            <a href="feedback.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 反馈筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">反馈状态：</label>
                            <select id="status" name="status" onchange="this.form.submit()">
                                <option value="-1">全部</option>
                                <option value="0" <?php echo $status_filter === 0 ? 'selected' : ''; ?>>未处理</option>
                                <option value="1" <?php echo $status_filter === 1 ? 'selected' : ''; ?>>已处理</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="type">反馈类型：</label>
                            <select id="type" name="type" onchange="this.form.submit()">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $type_filter == 1 ? 'selected' : ''; ?>>产品</option>
                                <option value="2" <?php echo $type_filter == 2 ? 'selected' : ''; ?>>服务</option>
                                <option value="3" <?php echo $type_filter == 3 ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 反馈列表 -->
            <div class="table-container">
                <h3>反馈列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>客户</th>
                            <th>类型</th>
                            <th>反馈内容</th>
                            <th>状态</th>
                            <th>提交时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($feedbacks)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无反馈数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($feedbacks as $feedback): ?>
                                <tr>
                                    <td><?php echo $feedback['id']; ?></td>
                                    <td><?php echo htmlspecialchars($feedback['client_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($feedback['type'] == 1) echo '产品';
                                        elseif ($feedback['type'] == 2) echo '服务';
                                        elseif ($feedback['type'] == 3) echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($feedback['content']); ?></td>
                                    <td>
                                        <?php
                                        if ($feedback['status'] == 0) echo '<span class="status-pending">未处理</span>';
                                        else echo '<span class="status-active">已处理</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($feedback['create_time'])); ?></td>
                                    <td>
                                        <?php if ($feedback['status'] == 0): ?>
                                            <form method="post" action="" style="display: inline;">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="feedback_id" value="<?php echo $feedback['id']; ?>">
                                                <input type="hidden" name="status" value="1">
                                                <button type="submit" class="btn btn-sm btn-success">标记为已处理</button>
                                            </form>
                                        <?php else: ?>
                                            <form method="post" action="" style="display: inline;">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="feedback_id" value="<?php echo $feedback['id']; ?>">
                                                <input type="hidden" name="status" value="0">
                                                <button type="submit" class="btn btn-sm btn-primary">标记为未处理</button>
                                            </form>
                                        <?php endif; ?>
                                        <form method="post" action="" style="display: inline;">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="feedback_id" value="<?php echo $feedback['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此反馈吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 使用说明 -->
            <div class="info-box">
                <h3>客户反馈管理说明</h3>
                <ul>
                    <li>本页面用于管理客户提交的反馈意见和建议。</li>
                    <li>您可以添加客户反馈信息，也可以为客户手动添加反馈。</li>
                    <li>反馈处理后，可以标记为"已处理"状态，便于跟踪管理。</li>
                    <li>反馈分为产品、服务和其他类型，便于分类处理。</li>
                    <li>您可以使用筛选功能查看不同状态和类型的反馈。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>